﻿;macros "FileSystem"
Macro FileExists(FileName)
	(FileSize(FileName) >= 0 And #True)
EndMacro

Macro PathExists(PathName)
	(FileSize(PathName) = -2 And #True)
EndMacro

Macro AddFileAttributes(File, Attributes)
	SetFileAttributes(File, GetFileAttributes(File) | Attributes)
EndMacro

Macro RemFileAttributes(File, Attributes)
	SetFileAttributes(File, GetFileAttributes(File) ! Attributes)
EndMacro

Macro HasFileAttributes(File, Attributes)
	(((GetFileAttributes(File) & Attributes) <> 0) Or #False)
EndMacro

;macros IsAscii (marche pas avec l'ascii étendu)
Macro IsUpper(c)
	((c >= 'A') And (c <= 'Z'))
EndMacro

Macro IsLower(c)
	((c >= 'a') And (c <= 'z'))
EndMacro

Macro IsAlpha(c)
	(IsUpper(c) Or IsLower(c))
EndMacro

Macro IsDigit(c)
	((c >= '0') And (c <= '9'))
EndMacro

Macro IsAlnum(c)
	(IsAlpha(c) Or IsDigit(c))
EndMacro

Macro IsXDigit(c)
	(IsDigit(c) Or ((c >= 'a') And (c <= 'f')) Or ((c >= 'A') And (c <= 'F')))
EndMacro

Macro IsPunct(c)
	((c = '"') Or FindString("!#%&'();<=>?[\]*+,-./:^_{|}~", Chr(c), 1))
EndMacro

Macro IsGraph(c)
	(IsAlnum(c) Or IsPunct(c))
EndMacro

Macro IsPrint(c)
	((c = ' ') Or IsGraph(c))
EndMacro

Macro IsSpace(c)
	((c = ' ') Or (c = #FF) Or (c = #LF) Or (c = #CR) Or (c = #HT) Or (c = #VT))
EndMacro

Macro IsBlank(c)
	((c = ' ') Or (c = #TAB))
EndMacro

Macro IsCntrl(c)
	((c = #BEL) Or (c = #BS))
EndMacro

Procedure.l IsNumeric(String.s)
	Protected Numeric.l, *String.Character
	
	If String
		Numeric = #True
		*String = @String
		
		While Numeric And *String\c
			Numeric = Bool(IsDigit(*String\c))
			*String + SizeOf(Character)
		Wend
	EndIf
	
	ProcedureReturn Numeric
EndProcedure

; Macros MakeInteger
; Fabrique un entier avec deux moitiés et récupère les deux moitiés d'un entier 
Macro MakeQuad(HiLong, LoLong)
	(HiLong << 32 | LoLong)
EndMacro

Macro HiLong(Quad)
	((Quad >> 32) & $FFFFFFFF)
EndMacro

Macro LoLong(Quad)
	(Quad & $FFFFFFFF)
EndMacro

Macro MakeLong(HiWord, LoWord)
	(HiWord << 16 | LoWord)
EndMacro

Macro HiWord(Long)
	((Long >> 16) & $FFFF)
EndMacro

Macro LoWord(Long)
	(Long & $FFFF)
EndMacro

Macro MakeWord(HiByte, LoByte)
	(HiByte << 8 | LoByte)
EndMacro

Macro HiByte(Word)
	((Word >> 8) & $FF)
EndMacro

Macro LoByte(Word)
	(Word & $FF)
EndMacro

Macro MakeByte(HiNibble, LoNibble)
	(HiNibble << 4 | LoNibble)
EndMacro

Macro HiNibble(Byte)
	((Byte >> 4) & $F)
EndMacro

Macro LoNibble(Byte)
	(Byte & $F)
EndMacro

;Pour inverser un LONG ( $22334455 -> $55443322 ) : 
Macro RevL(a)
	( ((a)>>24) | ((a)<<24) | (((a)&$FF0000)>>8) | (((a)&$FF00)<<8) )
EndMacro 

; Année Bissextile :
Macro IsLeapYear(year)
	((Not year%400) Or ((year%100) And (Not year%4)))
EndMacro

Macro BSwapW(Word)
	(((Word & $00FF) << 8) | ((Word & $FF00) >> 8))
EndMacro

Macro BSwapL(Long)
	(((Long&$FF000000)>>24) | ((Long&$FF)<<24) | (((Long)&$FF0000)>>8) | (((Long)&$FF00)<<8) )
EndMacro

Macro BSwapQ(Quad)
	(MakeQuad(BSwapL(LoLong(Quad)), BSwapL(HiLong(Quad))))
EndMacro

; a.q = $1122334455667788
; Debug Hex(a)
; a = BSwapQ(a)
; Debug Hex(a)

; Macros Memory
; pour copier et comparer des structures
; ca ne duplique/compare pas les chaines de caractère
; (y'avait tout un sujet sur une commande "CopyStructure" =)
; 
; ca sert juste de raccourci pour avoir un code plus lisible ^^ 
Macro Copy(Type, Source, Destination)
	CopyMemory(Source, Destination, SizeOf(Type#))
EndMacro

Macro Move(Type, Source, Destination)
	MoveMemory(Source, Destination, SizeOf(Type#))
EndMacro

Macro Compare(Type, Source1, Source2)
	CompareMemory(Source1, Source2, SizeOf(Type#))
EndMacro

; Define.LOGBRUSH brush1, brush2
; 
; ;initialise la structure
; With brush1
; 	\lbStyle = #BS_SOLID
; 	\lbColor = #White
; EndWith
; 
; ;copie la structure
; Copy(LOGBRUSH, brush1, brush2)
; 
; ;vérifie que brush1 = brush2
; If Compare(LOGBRUSH, brush1, brush2)
; 	;ca correspond, affiche la couleur
; 	Debug Hex(brush2\lbColor)
; EndIf

; avec la constante #PI native, voila des macros de conversion (relativement optimisées :P8)) 
#RadToDeg = 180.0 / #PI
#RadToGrd = 200.0 / #PI
#DegToRad = #PI / 180.0
#DegToGrd = 200 / 180.0
#GrdToRad = #PI / 200.0
#GrdToDeg = 180 / 200.0

Macro RadToDeg(Rad)
	((Rad) * #RadToDeg)
EndMacro

Macro RadToGrd(Rad)
	((Rad) * #RadToGrd)
EndMacro

Macro DegToRad(Deg)
	((Deg) * #DegToRad)
EndMacro

Macro DegToGrd(Deg)
	((Deg) * #DegToGrd)
EndMacro

Macro GrdToRad(Grd)
	((Grd) * #GrdToRad)
EndMacro

Macro GrdToDeg(Grd)
	((Grd) * #GrdToDeg)
EndMacro




; IDE Options = PureBasic 5.31 (Windows - x86)
; CursorPosition = 204
; FirstLine = 199
; Folding = --------
; EnableXP